#!/bin/sh
. ./build-env.sh

KMAKE_ALL=false
KMAKE_BUILD=true

if [ "x$1" = "x--pack-only" ]; then
  KMAKE_BUILD=false
fi


kmake() {
  BSP_BUILD_TARGET=$1
  echo ""
  echo make ${BSP_BUILD_TARGET}
  fakeroot make -j3 -f debian/rules.gen ${BSP_BUILD_TARGET}
  rc=$?

  if [ $rc != 0 ]; then
    fakeroot make -j1 -f debian/rules.gen ${BSP_BUILD_TARGET}
    rc=$?
  fi

  echo Done with return code $rc
  if [ $rc != 0 ]; then
    exit $rc
  fi
}


cd linux/

BSP_KERNELARCH=${BSP_ARCH}
if [ "${BSP_ARCH}" != "arm64" -a "${BSP_ARCH:0:3}" = arm ]; then
  BSP_KERNELARCH=arm
fi

BSP_CONFIG=debian/config/${BSP_ARCH}/config.${BSP_MODEL}
if [ -e debian/config/kernelarch-${BSP_KERNELARCH}/config.${BSP_MODEL} ]; then
  BSP_CONFIG=debian/config/kernelarch-${BSP_KERNELARCH}/config.${BSP_MODEL}
fi

MAJVERSION=`cat Makefile | grep -m1 -E '^VERSION.='    | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATVERSION=`cat Makefile | grep -m1 -E '^PATCHLEVEL.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep -m1 -E '^SUBLEVEL.='   | cut -d "=" -f 2- | tr -d " \t\n\r"`

export ARCH=${BSP_KERNELARCH}
#export LOCALVERSION="+${BSP_MODEL}"
LOCALVERSION=
export KBUILD_DEBARCH=${BSP_ARCH}
export KDEB_PKGVERSION="${MAJVERSION}.${PATVERSION}.${SUBVERSION}-20180104-${BSP_MODEL}"
export KZIP_PKGVERSION="${KDEB_PKGVERSION}"

export CC=gcc

if [ -e ${BSP_CONFIG} ]; then
  export KDEB_PKGVERSION="`echo ${lxdebvb} | sed s/'\+deb.u.'/${lxsocsa}/g`"
  export KZIP_PKGVERSION="${KDEB_PKGVERSION}-${BSP_MODEL}"
fi

cd ..

if $KMAKE_BUILD ; then
  echo "Building ${KZIP_PKGVERSION}..."

  cd linux/

  if [ -e ${BSP_CONFIG} ]; then
    mkdir -p debian/build

    #sed -i s/'gcc-4.6'/'gcc-4.8'/g debian/config/defines
    #sed -i s/'gcc-4.6'/'gcc-4.8'/g debian/config/*/defines

    sed -i s/'gcc-4.8'/'gcc-6'/g debian/config/defines
    sed -i s/'gcc-4.8'/'gcc-6'/g debian/config/*/defines

    fakeroot make -f debian/rules debian/control debian/rules.gen || true

    if $KMAKE_ALL ; then
      for c in `ls debian/config/${BSP_ARCH}/config.${BSP_MODEL:0:3}*`; do
        m=`basename $c`
        m=${m/config./}
        kmake binary-arch_${BSP_ARCH}_none_$m
      done

      kmake binary-arch_${BSP_ARCH}_none
    else
      if [ -e debian/build/build_${BSP_ARCH}_none_${BSP_MODEL} ]; then
        fakeroot make -j3 -C debian/build/build_${BSP_ARCH}_none_${BSP_MODEL}
      fi

      kmake binary-arch_${BSP_ARCH}_none_real
      kmake binary-arch_${BSP_ARCH}_none_${BSP_MODEL}
    fi

  else
    cp -p ../config .config

    make -j4 ARCH=${ARCH} CC=${CC} Image modules
    make ARCH=${ARCH} CC=${CC} dtbs

    make ARCH=${ARCH} CC=${CC} headers_check 
    make ARCH=${ARCH} CC=${CC} scripts

    make -j1 deb-pkg KDEB_PKGVERSION="${KDEB_PKGVERSION}" ARCH=${ARCH} CC=${CC} \
      KBUILD_DEBARCH=${KBUILD_DEBARCH} \
      DEBFULLNAME="BSP" \
      DEBEMAIL="developer@build.local"
  fi

  cd ..

  if [ -e linux/${BSP_CONFIG} ]; then
    sed -i s/'BSP_MODEL=.*'/'BSP_MODEL='${BSP_MODEL}/g build-meta.sh
    ./build-meta.sh
  fi
fi

mkdir -p dbg
mv linux-*${BSP_MODEL}*-dbg*_${KDEB_PKGVERSION}_*.deb dbg/

if [ -e linux/${BSP_CONFIG} ]; then
  echo linux-image-${KZIP_PKGVERSION}-${KBUILD_DEBARCH}.zip
  zip linux-image-${KZIP_PKGVERSION}-${KBUILD_DEBARCH}.zip flash-bb-env-and-kernel2.sh install-debian-linux.sh \
    linux-*${BSP_ARCH}_*_*.deb linux-*common*_${KDEB_PKGVERSION}_*.deb linux-*${BSP_MODEL}*_${KDEB_PKGVERSION}_*.deb linux-kbuild-*_*_*.deb *-barebox-boot.tar.gz

else
  echo linux-image-${KZIP_PKGVERSION}-${KBUILD_DEBARCH}.zip
  zip linux-image-${KZIP_PKGVERSION}-${KBUILD_DEBARCH}.zip flash-bb-env-and-kernel2.sh install-linux.sh \
    linux-*_${KDEB_PKGVERSION}_*.deb *-barebox-boot.tar.gz
fi

echo OK
